@@ -110,6 +110,8 @@ ebic.lm.bsreg <- function(target, dataset, gam = NULL, wei = NULL) {
     }  ## end if ( tool[2] > 0 )
    }  ## end  if ( bic0 - mat[sel, 2] < 0  )
   }  ## end  if (M == 0)
+    runtime <- proc.time() - tic
+    res <- list(runtime = runtime, info = info, mat = mat )
   }  ## end if ( p > n )
   
   res
