@@ -120,6 +120,8 @@ ebic.zip.bsreg <- function(target, dataset, wei = NULL, gam = NULL) {
       }  ## end if ( tool[2] > 0 )
     }  ## end if ( bic0 - mat[sel, 2] < 0  ) 
    }  ## end  if (M == 0)
+    runtime <- proc.time() - tic
+    res <- list(runtime = runtime, info = info, mat = mat )
   }  ##  end  if ( p > n )
   
   res
